summaryrefslogtreecommitdiff
path: root/lib
diff options
context:
space:
mode:
authorZach Copley <zach@status.net>2009-10-09 14:22:18 -0700
committerZach Copley <zach@status.net>2009-10-09 14:22:18 -0700
commitbb08611def2309711f91c1ab6cdab92fb7c069b2 (patch)
tree5742a4af66e7fd5f18b6726a3d8cd74543a12b88 /lib
parent09f4d1ef236c160afe6b9874793e43b501e1120a (diff)
Delete action/api.php and rename lib/twitterapi.php to lib/api.php
Diffstat (limited to 'lib')
-rw-r--r--lib/api.php (renamed from lib/twitterapi.php)32
-rw-r--r--lib/apiauth.php4
2 files changed, 28 insertions, 8 deletions
diff --git a/lib/apiauth.php b/lib/apiauth.php
index f0b4b6bf7..d7f8017eb 100644
--- a/lib/apiauth.php
+++ b/lib/apiauth.php
@@ -31,7 +31,7 @@ if (!defined('STATUSNET')) {
exit(1);
}
-require_once INSTALLDIR.'/lib/twitterapi.php';
+require_once INSTALLDIR.'/lib/api.php';
/**
* Actions extending this class will require auth
@@ -43,7 +43,7 @@ require_once INSTALLDIR.'/lib/twitterapi.php';
* @link http://status.net/
*/
-class ApiAuthAction extends TwitterapiAction
+class ApiAuthAction extends ApiAction
{
var $auth_user = null;
diff --git a/lib/twitterapi.php b/lib/api.php
index e5904cc85..93b4a7513 100644
--- a/lib/twitterapi.php
+++ b/lib/api.php
@@ -1,9 +1,12 @@
<?php
/*
* StatusNet - the distributed open-source microblogging tool
* Copyright (C) 2008, 2009, StatusNet, Inc.
*
- * This program is free software: you can redistribute it and/or modify
+ * PHP version 5
+ *
+ * LICENCE: This program is free software: you can redistribute it and/or modify
* it under the terms of the GNU Affero General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
* (at your option) any later version.
@@ -15,13 +18,30 @@
*
* You should have received a copy of the GNU Affero General Public License
* along with this program. If not, see <http://www.gnu.org/licenses/>.
+ *
+ * @category API
+ * @package StatusNet
+ * @author Zach Copley <zach@status.net>
+ * @copyright 2009 StatusNet, Inc.
+ * @license http://www.fsf.org/licensing/licenses/agpl-3.0.html GNU Affero General Public License version 3.0
+ * @link http://status.net/
*/
-if (!defined('STATUSNET') && !defined('LACONICA')) {
+if (!defined('STATUSNET')) {
exit(1);
}
-class TwitterapiAction extends Action
+/**
+ * Contains most of the Twitter-compatible API output functions.
+ *
+ * @category API
+ * @package StatusNet
+ * @author Zach Copley <zach@status.net>
+ * @license http://www.fsf.org/licensing/licenses/agpl-3.0.html GNU Affero General Public License version 3.0
+ * @link http://status.net/
+ */
+
+class ApiAction extends Action
{
/**
@@ -1,9 +1,12 @@
<?php
-/*
- * StatusNet - the distributed open-source microblogging tool
- * Copyright (C) 2008, 2009, StatusNet, Inc.
+/**
+ * StatusNet, the distributed open-source microblogging tool
+ *
+ * Base API action
*